Simple content management system for Django 1.6+
================================================

``django-pages-cms`` is a simple content management system for Django 1.6+

.. image:: https://travis-ci.org/dlancer/django-pages-cms.svg?branch=master
    :target: https://travis-ci.org/dlancer/django-pages-cms/
    :alt: Build status

.. image:: https://pypip.in/version/django-pages-cms/badge.svg
    :target: https://pypi.python.org/pypi/django-pages-cms/
    :alt: Latest PyPI version

.. image:: https://pypip.in/download/django-pages-cms/badge.svg
    :target: https://pypi.python.org/pypi/django-pages-cms/
    :alt: Number of PyPI downloads

.. image:: https://pypip.in/format/django-pages-cms/badge.svg
    :target: https://pypi.python.org/pypi/django-pages-cms/
    :alt: Download format

.. image:: https://pypip.in/license/django-pages-cms/badge.svg
    :target: https://pypi.python.org/pypi/django-pages-cms/
    :alt: License

Requirements
------------

::

    Django>=1.6
    django-appcore==0.0.4
    django-mptt==0.7.0
    django-guardian==1.2.5
    django-image-cropping==0.1.0
    django-markitup==2.2.2
    django-taggit==0.13.0
    easy-thumbnails==2.2
    PyYAML==3.11
    Markdown==2.6.1

If you use Django<1.7, you should install South==1.0.2

Usage
=====

You may find detailed documentation is in the "docs" directory.

